@@ -145,7 +145,7 @@ class BakedQuery(object):
          :class:`.BakedQuery` object subsequent to the spoil step will be
          non-cached; the state of the :class:`.BakedQuery` up until
          this point will be pulled from the cache.   If True, then the
-         entire :class:`.Query` object is built from scratch each
+         entire :class:`_query.Query` object is built from scratch each
          time, with all creational functions being called on each
          invocation.
 
@@ -163,16 +163,15 @@ class BakedQuery(object):
         :class:`.Session`.
 
         This basically means we also will include the session's query_class,
-        as the actual :class:`.Query` object is part of what's cached
-        and needs to match the type of :class:`.Query` that a later
+        as the actual :class:`_query.Query` object is part of what's cached
+        and needs to match the type of :class:`_query.Query` that a later
         session will want to use.
 
         """
         return self._cache_key + (session._query_cls,)
 
     def _with_lazyload_options(self, options, effective_path, cache_path=None):
-        """Cloning version of _add_lazyload_options.
-        """
+        """Cloning version of _add_lazyload_options."""
         q = self._clone()
         q._add_lazyload_options(options, effective_path, cache_path=cache_path)
         return q
@@ -195,12 +194,12 @@ class BakedQuery(object):
         if cache_path.path[0].is_aliased_class:
             # paths that are against an AliasedClass are unsafe to cache
             # with since the AliasedClass is an ad-hoc object.
-            self.spoil()
+            self.spoil(full=True)
         else:
             for opt in options:
                 cache_key = opt._generate_cache_key(cache_path)
                 if cache_key is False:
-                    self.spoil()
+                    self.spoil(full=True)
                 elif cache_key is not None:
                     key += cache_key
 
@@ -253,11 +252,11 @@ class BakedQuery(object):
         return context
 
     def to_query(self, query_or_session):
-        """Return the :class:`.Query` object for use as a subquery.
+        """Return the :class:`_query.Query` object for use as a subquery.
 
         This method should be used within the lambda callable being used
         to generate a step of an enclosing :class:`.BakedQuery`.   The
-        parameter should normally be the :class:`.Query` object that
+        parameter should normally be the :class:`_query.Query` object that
         is passed to the lambda::
 
             sub_bq = self.bakery(lambda s: s.query(User.name))
@@ -279,7 +278,7 @@ class BakedQuery(object):
                 lambda s: s.query(Address.id, sub_bq.to_query(q).as_scalar())
             )
 
-        :param query_or_session: a :class:`.Query` object or a class
+        :param query_or_session: a :class:`_query.Query` object or a class
          :class:`.Session` object, that is assumed to be within the context
          of an enclosing :class:`.BakedQuery` callable.
 
@@ -391,13 +390,14 @@ class Result(object):
         """Add a criteria function that will be applied post-cache.
 
         This adds a function that will be run against the
-        :class:`.Query` object after it is retrieved from the
+        :class:`_query.Query` object after it is retrieved from the
         cache.    Functions here can be used to alter the query in ways
         that **do not affect the SQL output**, such as execution options
         and shard identifiers (when using a shard-enabled query object)
 
         .. warning::  :meth:`.Result.with_post_criteria` functions are applied
-           to the :class:`.Query` object **after** the query's SQL statement
+           to the :class:`_query.Query`
+           object **after** the query's SQL statement
            object has been retrieved from the cache.   Any operations here
            which intend to modify the SQL should ensure that
            :meth:`.BakedQuery.spoil` was called first.
@@ -446,7 +446,7 @@ class Result(object):
     def count(self):
         """return the 'count'.
 
-        Equivalent to :meth:`.Query.count`.
+        Equivalent to :meth:`_query.Query.count`.
 
         Note this uses a subquery to ensure an accurate count regardless
         of the structure of the original statement.
@@ -464,7 +464,7 @@ class Result(object):
         if no rows present.  If multiple rows are returned,
         raises MultipleResultsFound.
 
-        Equivalent to :meth:`.Query.scalar`.
+        Equivalent to :meth:`_query.Query.scalar`.
 
         .. versionadded:: 1.1.6
 
@@ -480,7 +480,7 @@ class Result(object):
     def first(self):
         """Return the first row.
 
-        Equivalent to :meth:`.Query.first`.
+        Equivalent to :meth:`_query.Query.first`.
 
         """
         bq = self.bq.with_criteria(lambda q: q.slice(0, 1))
@@ -497,14 +497,17 @@ class Result(object):
     def one(self):
         """Return exactly one result or raise an exception.
 
-        Equivalent to :meth:`.Query.one`.
+        Equivalent to :meth:`_query.Query.one`.
 
         """
         try:
             ret = self.one_or_none()
-        except orm_exc.MultipleResultsFound:
-            raise orm_exc.MultipleResultsFound(
-                "Multiple rows were found for one()"
+        except orm_exc.MultipleResultsFound as err:
+            util.raise_(
+                orm_exc.MultipleResultsFound(
+                    "Multiple rows were found for one()"
+                ),
+                replace_context=err,
             )
         else:
             if ret is None:
@@ -515,7 +518,7 @@ class Result(object):
         """Return one or zero results, or raise an exception for multiple
         rows.
 
-        Equivalent to :meth:`.Query.one_or_none`.
+        Equivalent to :meth:`_query.Query.one_or_none`.
 
         .. versionadded:: 1.0.9
 
@@ -535,7 +538,7 @@ class Result(object):
     def all(self):
         """Return all rows.
 
-        Equivalent to :meth:`.Query.all`.
+        Equivalent to :meth:`_query.Query.all`.
 
         """
         return list(self)
@@ -543,7 +546,7 @@ class Result(object):
     def get(self, ident):
         """Retrieve an object based on identity.
 
-        Equivalent to :meth:`.Query.get`.
+        Equivalent to :meth:`_query.Query.get`.
 
         """
 
@@ -640,7 +643,7 @@ def unbake_lazy_loaders():
 
     This method now raises NotImplementedError() as the "baked" implementation
     is the only lazy load implementation.  The
-    :paramref:`.relationship.bake_queries` flag may be used to disable
+    :paramref:`_orm.relationship.bake_queries` flag may be used to disable
     the caching of queries on a per-relationship basis.
 
     """
